
# Slot: issue


issue of a newspaper, a scientific journal or magazine for reference purpose

URI: [biolink:issue](https://w3id.org/biolink/vocab/issue)


## Domain and Range

[Publication](Publication.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [Article](Article.md)
 * [Serial](Serial.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | WIKIDATA_PROPERTY:P433 |

